ap

Dependencies:   DnsQuery

Dependents:   WizFi310_TCP_Echo_Server_Example

Fork of NetworkSocketAPI by NetworkSocketAPI

Branch:
api-changes
Revision:
24:a5e959bdd2dd
Parent:
21:35ed15069189
Child:
25:ed7b2a52e8ac
--- a/UDPSocket.h	Thu Feb 18 04:05:09 2016 -0600
+++ b/UDPSocket.h	Thu Feb 18 04:09:00 2016 -0600
@@ -28,16 +28,22 @@
 public:
     /** Create a socket using the specified network interface
      *  @param iface The network interface to use
      *  @param ip Optional ip address to connect to, copied internally
      *  @param port Optional port to connect to
      */
-    UDPSocket(NetworkInterface *iface, const char *ip = 0, uint16_t port = 0);
+    UDPSocket(NetworkInterface *iface, const char *url = 0, uint16_t port = 0);
 
     /** Closes and destroys the socket
      */
     ~UDPSocket();
 
 
+    /** Set the URL of the socket
+     *  Performs DNS lookup if necessary
+     *  @param url URL to connect to
+     */
+    void setURL(const char *url);
+
     /** Set the IP address of the socket
      *  @param ip IP address to connect to, copied internally
      */
@@ -28,16 +28,22 @@
     /** Create a socket using the specified network interface
      *  @param iface The network interface to use
-     *  @param ip Optional ip address to connect to, copied internally
+     *  @param ip Optional URL to connect to, copied internally
      *  @param port Optional port to connect to
      */